@@ -2,7 +2,7 @@
 package #1;
 
 
-import #1.base.*;
+import #1.#x.*;
 import paraselene.*;
 import paraselene.supervisor.*;
 
