@@ -1,5 +1,5 @@
 // Paraselene generated this source file.
-package #1.view#2;
+package #1.#y#2;
 
 import paraselene.supervisor.*;
 
@@ -22,10 +22,10 @@ Option.debug( e );
 }
 /**
  * ページIDの取得。
- * @return ページID。#1.base.PageType.#6。
+ * @return ページID。#1.#x.PageType.#6。
  */
 public PageID getID() {
-return #1.base.PageType.#6;
+return #1.#x.PageType.#6;
 }
 /**
  * ブラウザに403を返す。
