@@ -12,7 +12,7 @@ import paraselene.tag.*;
 import paraselene.css.*;
 
 /**
- * 色を示す文字列。スレッドセーフです。
+ * 色を示す文字列。
  */
 public class Color extends PlainText implements AttributeValuable, CSSValuable {
 	private static final long serialVersionUID = 2L;
@@ -22,7 +22,7 @@ public class Color extends PlainText implements AttributeValuable, CSSValuable {
 	 * 複製の作成。
 	 * @return 複製。
 	 */
-	public synchronized HTMLPart getReplica() {
+	public HTMLPart getReplica() {
 		return new Color( red, green, blue );
 	}
 
@@ -95,7 +95,7 @@ public class Color extends PlainText implements AttributeValuable, CSSValuable {
 	 * @param g 緑(0x00 ～ 0xff)。負数の場合、transparent となります。
 	 * @param b 青(0x00 ～ 0xff)。負数の場合、transparent となります。
 	 */
-	public synchronized void setColor( int r, int g, int b ) {
+	public void setColor( int r, int g, int b ) {
 		if ( r < 0 || g < 0 || b < 0 ) {
 			red = green = blue = -1;
 			super.setText( "transparent" );
