@@ -18,7 +18,7 @@ import paraselene.tag.form.*;
 
 
 /**
- * HTMLページ。スレッドセーフです。
+ * HTMLページ。
  */
 public abstract class Page implements Serializable {
 	/**
@@ -225,7 +225,7 @@ public abstract class Page implements Serializable {
 	 * @param xml true:XHTML, false:HTML。
 	 * @param doctype &lt;!DOCTYPE ～ &gt;の文字列。不要であればnull。
 	 */
-	protected synchronized void setDoctype( boolean xml, String doctype ) {
+	protected void setDoctype( boolean xml, String doctype ) {
 		xml_f = xml;
 		doctype_def = doctype;
 	}
@@ -249,7 +249,7 @@ public abstract class Page implements Serializable {
 	/**
 	 * タグの全消去。
 	 */
-	public synchronized void clear() {
+	public void clear() {
 		tag_1_dic = new HashMap<String,Tag>();
 		tag_m_dic = new HashMap<String,HashMap<String,Tag>>();
 		name_dic = new HashMap<Tag,String>();
@@ -291,10 +291,8 @@ public abstract class Page implements Serializable {
 	 */
 	public String[] getDefineNameIndex() {
 		ArrayList<String>	list = new ArrayList<String>();
-		synchronized( this ) {
-			for ( String k:	tag_m_dic.keySet() ) {
-				list.add( k );
-			}
+		for ( String k:	tag_m_dic.keySet() ) {
+			list.add( k );
 		}
 		return list.toArray( new String[0] );
 	}
@@ -305,15 +303,13 @@ public abstract class Page implements Serializable {
 	 */
 	public String[] getDefineName() {
 		ArrayList<String>	list = new ArrayList<String>();
-		synchronized( this ) {
-			for ( String k: tag_1_dic.keySet() ) {
-				list.add( k );
-			}
+		for ( String k: tag_1_dic.keySet() ) {
+			list.add( k );
 		}
 		return list.toArray( new String[0] );
 	}
 
-	private synchronized ArrayList<Form> getForm( Tag tag, ArrayList<Form> list ) {
+	private ArrayList<Form> getForm( Tag tag, ArrayList<Form> list ) {
 		Tag[]	nest = tag.getTagArray();
 		for ( int i = 0; i < nest.length; i++ ) {
 			list = getForm( nest[i], list );
@@ -351,7 +347,7 @@ public abstract class Page implements Serializable {
 	 * 通常のコーディングであればプログラマはこのメソッドを使う事はありません。
 	 * @param req リクエスト。
 	 */
-	public synchronized void reflect( RequestParameter req ) {
+	public void reflect( RequestParameter req ) {
 		modified = new Control[0];
 		if ( getMainTag() == null )	return;
 		ArrayList<Form>	form = getForm( getMainTag(), new ArrayList<Form>() );
@@ -394,7 +390,7 @@ public abstract class Page implements Serializable {
 	 * 押下ボタンの取得。
 	 * @return 押下ボタン。無ければnull。
 	 */
-	public synchronized Button getClickedButton() {
+	public Button getClickedButton() {
 		if ( getMainTag() == null )	return null;
 		ArrayList<Form>	form = getForm( getMainTag(), new ArrayList<Form>() );
 		int	size = form.size();
@@ -453,7 +449,7 @@ public abstract class Page implements Serializable {
 	 * 不要な場合はnullを指定して下さい。
 	 * @param query クエリー。エスケープしないで下さい。
 	 * @return URI属性。
-	 * @exception PageException new URIAttributeで例外が発生した。
+	 * @exception PageException new URIValueで例外が発生した。
 	 */
 	public Attribute createPageToURI( String name, PageID pid, String fragment,
 	QueryItem ... query ) throws PageException {
@@ -469,7 +465,7 @@ public abstract class Page implements Serializable {
 	 * @param filename ブラウザに認識させるファイル名。
 	 * @param query クエリー。エスケープしないで下さい。
 	 * @return URI属性。
-	 * @exception PageException new URIAttributeで例外が発生した。
+	 * @exception PageException new URIValueで例外が発生した。
 	 */
 	public Attribute createPageToDownloadURI( String name, PageID pid,
 	String filename, QueryItem ... query ) throws PageException {
@@ -491,7 +487,7 @@ public abstract class Page implements Serializable {
 	 * @param query クエリー。エスケープしないで下さい。
 	 * @return URI属性。
 	 * @exception PageException 別名URIを持たないページを指定した。
-	 * new URIAttributeで例外が発生した。先頭一致URIに対して、bodyにnullを指定した。
+	 * new URIValueで例外が発生した。先頭一致URIに対して、bodyにnullを指定した。
 	 */
 	public Attribute createAliasToURI( String name, PageID pid, String body, String fragment, QueryItem ... query ) throws PageException {
 		PageFactory	factory = pid.getPageFactory();
@@ -563,26 +559,25 @@ public abstract class Page implements Serializable {
 	 * @param name タグのname属性値。
 	 * @return タグ。配列化されたタグならnullを返します。
 	 */
-	public synchronized Tag getTag( String name ) {
+	public Tag getTag( String name ) {
 		return tag_1_dic.get( name );
 	}
 
 	/**
-	 * タグの取得。配列で返します。
+	 * タグの取得。配列で返します。HTML先頭からの登場順にソートされています。
 	 * @param name タグのname属性値。
 	 * @return タグ。
 	 */
 	public Tag[] getAllTag( String name ) {
+		if ( name == null )	return new Tag[0];
 		String[]	pre = name.split( "\\$" );
 		ArrayList<Tag>	list = new ArrayList<Tag>();
-		synchronized( this ) {
-			HashMap<String,Tag>	map = tag_m_dic.get( pre[0] );
-			if ( map == null )	return null;
-			for ( String k : map.keySet() ) {
-				list.add( map.get( k ) );
-			}
+		HashMap<String,Tag>	map = tag_m_dic.get( pre[0] );
+		if ( map == null )	return new Tag[0];
+		for ( String k : map.keySet() ) {
+			list.add( map.get( k ) );
 		}
-		return list.toArray( new Tag[0] );
+		return Tag.sort( list.toArray( new Tag[0] ) );
 	}
 
 	/**
@@ -635,7 +630,7 @@ public abstract class Page implements Serializable {
 		return idx[0];
 	}
 
-	private synchronized void clearDic( String name ) {
+	private void clearDic( String name ) {
 		Tag	tag = tag_1_dic.remove( name );
 		name_dic.remove( tag );
 		String	index = getIndexName( name );
@@ -650,16 +645,14 @@ public abstract class Page implements Serializable {
 	private String extendName( Tag tag ) {
 		String	org_name = tag.getNameAttribute();
 		String	index = getIndexName( org_name );
-		synchronized( this ) {
-			for ( ; ; name_seq++ ) {
-				org_name = String.format( "%s$%d", index, name_seq );
-				if ( tag_1_dic.get( org_name ) == null )	break;
-			}
+		for ( ; ; name_seq++ ) {
+			org_name = String.format( "%s$%d", index, name_seq );
+			if ( tag_1_dic.get( org_name ) == null )	break;
 		}
 		return org_name;
 	}
 
-	private synchronized void nameTagSingle(Tag tag ) {
+	private void nameTagSingle(Tag tag ) {
 		if ( tag == null )	return;
 		String	old_name = name_dic.get( tag );
 		String	new_name = tag.getNameAttribute();
@@ -695,7 +688,7 @@ public abstract class Page implements Serializable {
 	 * タグのname検証。衝突が見つかればnameを変更する。
 	 * @param tag 検証対象。
 	 */
-	public synchronized void nameTag( Tag tag ) {
+	public void nameTag( Tag tag ) {
 		if ( getMainTag() == null )	return;
 		tag.setAssignedPage( this );
 		String	name = tag.getNameAttribute();
@@ -724,7 +717,7 @@ public abstract class Page implements Serializable {
 	 * タグエントリーの除去。
 	 * @param tag 除去対象。
 	 */
-	public synchronized void removeNameEntry( Tag tag ) {
+	public void removeNameEntry( Tag tag ) {
 		if ( getMainTag() == null )	return;
 		ArrayList<Form>	form = getForm( getMainTag(), new ArrayList<Form>() );
 		int cnt = form.size();
@@ -760,7 +753,7 @@ public abstract class Page implements Serializable {
 	 * HTMLタグの登録。
 	 * @param tag HTMLタグ。
 	 */
-	public synchronized void setMainTag( Tag tag ) {
+	public void setMainTag( Tag tag ) {
 		if ( contents != null ) {
 			clearAssignedPage( contents );
 		}
@@ -804,7 +797,7 @@ public abstract class Page implements Serializable {
 	/**
 	 * タグの取得。AやTABLEのような、タグの種別で探します。再帰的に探します。
 	 * @param name タグの種別。
-	 * @return タグの配列。無ければ0個の配列を返す。
+	 * @return タグの配列。無ければ0個の配列を返す。登場順にソートされてます。
 	 * ただし、nameがnullなら、nullを返す。
 	 */
 	public Tag[] getAllTagByType( String name ) {
@@ -829,7 +822,7 @@ public abstract class Page implements Serializable {
 	 * @param to 新規設定インスタンス。
 	 * @param copy_f true:内容をコピーする、false:内容のコピーは行わない。
 	 */
-	public synchronized void replaceTag( Tag from, Tag to, boolean copy_f ) {
+	public void replaceTag( Tag from, Tag to, boolean copy_f ) {
 		if ( getMainTag() == null )	return;
 		Tag	tag = getMainTag().getDirectInnerTag( from );
 		int	idx = tag.indexOf( from );
