@@ -23,6 +23,12 @@ public class Make implements OutputNo {
 			return Param.PACKAGE.get();
 		case 2:
 			return Param.OUT_ENCODE.get();
+		case 33:
+			return Param.PACKAGE_BASE.get();
+		case 34:
+			return Param.PACKAGE_VIEW.get();
+		case 35:
+			return Param.PACKAGE_LOGIC.get();
 		}
 		return null;
 	}
@@ -201,7 +207,7 @@ public class Make implements OutputNo {
 			Output.rmdir( buf.toString() );
 			buf = new StringBuilder( SRC_PATH );
 			buf = buf.append( File.separator );
-			buf = buf.append( "base" );
+			buf = buf.append( Param.PACKAGE_BASE.get() );
 			Output.rmdir( buf.toString() );
 		}
 
