@@ -7,9 +7,9 @@
 package paraselene.mockup.css;
 public class paraselene_css extends paraselene.mockup.Output {
 protected String getFileByte() { return
-"table{border: 1px solid  #000;border-collapse : collapse ;}";}
+"table{empty-cells:show;}";}
 public paraselene.HTTPDate getDate() { try{
-return new paraselene.HTTPDate("Sun, 08 Nov 2009 07:53:21 GMT");
+return new paraselene.HTTPDate("Tue, 10 Nov 2009 15:44:35 GMT");
 }catch(Exception e){}
 return null;
 }
