@@ -123,7 +123,7 @@ public class Forward implements Serializable {
 			return;
 		}
 		if ( redirect_uri != null ) {
-			res.sendRedirect( Supervisor.makeWithSessionURI( redirect_uri.toString(), null ) );
+			res.sendRedirect( Supervisor.makeWithSessionURI( redirect_uri.toString(), null, null ) );
 			return;
 		}
 	}
