@@ -16,13 +16,16 @@ import paraselene.*;
  * スレッドセーフです。
  */
 public class History implements Serializable {
-	private static final long serialVersionUID = 1L;
+	private static final long serialVersionUID = 2L;
 	private ArrayList<Page>	hist = new ArrayList<Page>();
+	private int	histry_no;
 
 	/**
 	 * コンストラクタ。
 	 */
-	public History() {
+	private History() {}
+	History( int n ) {
+		histry_no = n;
 	}
 
 	/**
@@ -38,13 +41,16 @@ public class History implements Serializable {
 					Page	h = hist.get( i );
 					if ( page.equals( h ) ) {
 						for ( int j = cnt -1; j >= i; j-- ) {
-							hist.remove( j );
+							hist.remove( j ).setHistoryKey( HistorySet.ROOT );
 						}
 						break;
 					}
 				}
 			}
-			if ( page.isAllowHistoryAdd() )	hist.add( page );
+			if ( page.isAllowHistoryAdd() ) {
+				hist.add( page );
+				page.setHistoryKey( histry_no );
+			}
 		}
 	}
 
@@ -86,7 +92,7 @@ public class History implements Serializable {
 			int	cnt = getHistoryCount();
 			for ( int i = cnt - 1; i >= 0; i-- ) {
 				if ( last_no == 0 )	{
-					hist.remove( i );
+					hist.remove( i ).setHistoryKey( HistorySet.ROOT );
 					return;
 				}
 				last_no--;
@@ -104,7 +110,7 @@ public class History implements Serializable {
 			for ( int i = cnt - 1; i >= 0; i-- ) {
 				Page	page = hist.get( i );
 				if ( page.getID() == page_id )	{
-					hist.remove( i );
+					hist.remove( i ).setHistoryKey( HistorySet.ROOT );
 				}
 			}
 		}
@@ -115,6 +121,10 @@ public class History implements Serializable {
 	 */
 	public void removePage() {
 		synchronized( hist ) {
+			int	cnt = getHistoryCount();
+			for ( int i = 0; i < cnt; i++ ) {
+				hist.get( i ).setHistoryKey( HistorySet.ROOT );
+			}
 			hist.clear();
 		}
 	}
