@@ -199,18 +199,21 @@ public abstract class Supervisor extends HttpServlet {
 			uri = holder.response.encodeURL( URIValue.encode( uri, enc ) );
 		}
 		else {
-			try {
-				uri = URIValue.encode( uri, enc );
-				URI	test = new URI( uri );
-				if ( !test.isAbsolute() ) {
-					uri = holder.response.encodeURL( uri );
-				}
-				else if ( test.getHost().equals( holder.req.getServerName() ) ) {
-					uri = holder.response.encodeURL( uri );
-				}
+			if ( holder.sv.getPageFactory().isAlias( uri ) && to_key != HistorySet.ROOT ) {
+				StringBuilder	buf = new StringBuilder( TransactionSequencer.SELENE[5] );
+				buf = buf.append( "." );
+				buf = buf.append( Integer.toString( to_key, Character.MAX_RADIX ) );
+				buf = buf.append( "." );
+				buf = buf.append( TransactionSequencer.SELENE[6] );
+				buf = buf.append( "." );
+				buf = buf.append( uri );
+				uri = buf.toString();
 			}
-			catch( Exception e ) {
-				Option.debug( e );
+			if ( isMyHost( uri ) ) {
+				uri = holder.response.encodeURL( URIValue.encode( uri, enc ) );
+			}
+			else {
+				uri = URIValue.encode( uri, enc );
 			}
 		}
 		if ( head != null ) {
@@ -222,6 +225,25 @@ public abstract class Supervisor extends HttpServlet {
 		return uri;
 	}
 
+	static boolean isMyHost( String uri ) {
+		DataHolder	holder = null;
+		synchronized( data_map_th ) {
+			holder = data_map_th.get( Thread.currentThread() );
+		}
+		if ( holder == null )	return false;
+		try {
+			URI	test = new URI( URIValue.encode( uri, "utf-8" ) );
+			if ( !test.isAbsolute() )	return true;
+			String	host = test.getHost();
+			if ( host == null )	return true;
+			if ( host.equals( holder.req.getServerName() ) )	return true;
+		}
+		catch( Exception e ){
+			Option.debug( e );
+		}
+		return false;
+	}
+
 	/**
 	 * ページファクトリーの取得。
 	 * @return ページファクトリー。
@@ -308,8 +330,9 @@ public abstract class Supervisor extends HttpServlet {
 			PathData	path_data = new PathData();
 			Forward	fw = null;
 			Page	last_page = null, next_page = null;
+			AliasData	alias = fact.getPage( uri );
 
-			if ( (path_data.to = fact.getPage( uri )) == null ) {
+			if ( alias == null ) {
 				path_data = TransactionSequencer.parsePath( data.seq, uri, fact, data.hist );
 				if ( TransactionSequencer.isMustSession( uri ) ) {
 					if ( holder.search_engine ) {
@@ -334,6 +357,8 @@ public abstract class Supervisor extends HttpServlet {
 			}
 			else {
 				path_data.from = null4alias;
+				path_data.to = alias.page;
+				path_data.to_histry = alias.to_histry;
 			}
 			if ( path_data == null ) {
 				fw = new Forward( 403 );
