@@ -9,13 +9,13 @@ package paraselene.tag;
 import java.io.*;
 import java.net.*;
 import java.util.*;
+import java.math.*;
 import paraselene.*;
 import paraselene.tag.*;
 import paraselene.mockup.*;
 
 /**
  * HTMLタグの属性。
- * スレッドセーフです。
  */
 public class Attribute implements Serializable {
 	private static final long serialVersionUID = 2L;
@@ -25,7 +25,7 @@ public class Attribute implements Serializable {
 
 	protected Attribute() {}
 
-	synchronized void setAssignedTag( Tag t ) {
+	void setAssignedTag( Tag t ) {
 		if ( t == null )	t = HTMLPart.getDummyTag();
 		embed_tag = t;
 		if ( value != null ) {
@@ -56,6 +56,33 @@ public class Attribute implements Serializable {
 		set( v );
 	}
 
+	/**
+	 * コンストラクタ。nは小文字に変換される。
+	 * @param n 属性名。
+	 * @param v 属性値。
+	 */
+	public Attribute( String n, int v ) {
+		this( n, new NumberValue( v ) );
+	}
+
+	/**
+	 * コンストラクタ。nは小文字に変換される。
+	 * @param n 属性名。
+	 * @param v 属性値。
+	 */
+	public Attribute( String n, double v ) {
+		this( n, new NumberValue( v ) );
+	}
+
+	/**
+	 * コンストラクタ。nは小文字に変換される。
+	 * @param n 属性名。
+	 * @param v 属性値。
+	 */
+	public Attribute( String n, BigDecimal v ) {
+		this( n, new NumberValue( v ) );
+	}
+
 	/**
 	 * コンストラクタ。nは小文字に変換される。
 	 * 値を持たない属性を作成します。
