@@ -158,8 +158,8 @@ public class CheckBox extends Input {
 	 * @param flag true:チェックする、false:チェック解除する。
 	 */
 	public void setChecked( boolean flag ) {
-		if ( radio_flag && flag && embed != null ) {
-			Tag[]	tag = embed.getAllTagByType( "form" );
+		if ( radio_flag && flag ) {
+			Tag[]	tag = getAssignedTag().getAssignedPage().getAllTagByType( "form" );
 			for ( int i = 0; i < tag.length; i++ ) {
 				if ( !(tag[i] instanceof Form) )	continue;
 				Form	form = (Form)tag[i];
