@@ -76,7 +76,7 @@ public class Form extends Tag {
 	 * 削除要素の検証。
 	 * @param tag 削除要素。
 	 */
-	public synchronized void checkTag4rm( Tag tag ) {
+	public void checkTag4rm( Tag tag ) {
 		Tag[]	in_tag = tag.getTagArray();
 		for ( int i = 0; i < in_tag.length; i++ ) {
 			checkTag4rm( in_tag[i] );
@@ -108,7 +108,7 @@ public class Form extends Tag {
 	 * 全てのコントロールの取得。
 	 * @return コントロール配列。存在しない場合、0個の配列を返します。
 	 */
-	public synchronized Control[] getAllControl() {
+	public Control[] getAllControl() {
 		ArrayList<Control>	list = new ArrayList<Control>();
 		for ( String	all_k: control.keySet() ) {
 			HashMap<String,Control>	map = control.get( all_k );
@@ -124,7 +124,7 @@ public class Form extends Tag {
 	 * @param name コントロールのname属性。
 	 * @return コントロール配列。存在しない場合、0個の配列を返します。
 	 */
-	public synchronized Control[] getAllControl( String name ) {
+	public Control[] getAllControl( String name ) {
 		ArrayList<Control>  list = new ArrayList<Control>();
 		HashMap<String,Control>	map = control.get( Page.getIndexName( name ) );
 		if ( map != null ) {
@@ -150,7 +150,7 @@ public class Form extends Tag {
 	 * 追加要素の検証。
 	 * @param tag 追加要素。
 	 */
-	public synchronized void checkTag( Tag tag ) {
+	public void checkTag( Tag tag ) {
 		Tag[]	in_tag = tag.getTagArray();
 		for ( int i = 0; i < in_tag.length; i++ ) {
 			checkTag( in_tag[i] );
@@ -188,7 +188,7 @@ public class Form extends Tag {
 	 * @param req リクエスト。
 	 * @return 変更のあったコントロール。
 	 */
-	public synchronized ArrayList<Control> reflect( RequestParameter req ) {
+	public ArrayList<Control> reflect( RequestParameter req ) {
 		Control[]	cont = getAllControl();
 		ArrayList<Control>	set = new ArrayList<Control>();
 		HashMap<String, CheckBox>	after = new HashMap<String, CheckBox>();
